import { type z } from 'zod';

import { type requestDataFormSchema } from '@/components/threads/messages/aitp/schema/data';

export async function GET() {
  const form: z.infer<typeof requestDataFormSchema> = {
    fields: [
      {
        id: 'full_name',
        label: 'Full Name',
        type: 'text',
        required: true,
        autocomplete: 'name',
      },
      {
        id: 'phone',
        label: 'Phone',
        type: 'tel',
        required: true,
        autocomplete: 'tel-national',
      },
      {
        id: 'email_address',
        label: 'Email Address',
        type: 'email',
        required: true,
        description:
          'Order and tracking information will be sent to this email',
        autocomplete: 'email',
      },
      {
        id: 'address_line_1',
        label: 'Address Line 1',
        type: 'text',
        description: 'Street address, P.O. box, company name, etc',
        autocomplete: 'address-line1',
        required: true,
      },
      {
        id: 'address_line_2',
        label: 'Address Line 2',
        type: 'text',
        description: 'Apartment, suite, unit, building, floor, etc',
        autocomplete: 'address-line2',
        required: false,
      },
      {
        id: 'city',
        label: 'City',
        type: 'text',
        autocomplete: 'address-level2',
        required: true,
      },
      {
        id: 'state',
        label: 'State',
        type: 'select',
        autocomplete: 'address-level1',
        required: true,
        options: [
          { value: 'AL', label: 'Alabama' },
          { value: 'AK', label: 'Alaska' },
          { value: 'AZ', label: 'Arizona' },
          { value: 'AR', label: 'Arkansas' },
          { value: 'CA', label: 'California' },
          { value: 'CO', label: 'Colorado' },
          { value: 'CT', label: 'Connecticut' },
          { value: 'DE', label: 'Delaware' },
          { value: 'DC', label: 'District Of Columbia' },
          { value: 'FL', label: 'Florida' },
          { value: 'GA', label: 'Georgia' },
          { value: 'HI', label: 'Hawaii' },
          { value: 'ID', label: 'Idaho' },
          { value: 'IL', label: 'Illinois' },
          { value: 'IN', label: 'Indiana' },
          { value: 'IA', label: 'Iowa' },
          { value: 'KS', label: 'Kansas' },
          { value: 'KY', label: 'Kentucky' },
          { value: 'LA', label: 'Louisiana' },
          { value: 'ME', label: 'Maine' },
          { value: 'MD', label: 'Maryland' },
          { value: 'MA', label: 'Massachusetts' },
          { value: 'MI', label: 'Michigan' },
          { value: 'MN', label: 'Minnesota' },
          { value: 'MS', label: 'Mississippi' },
          { value: 'MO', label: 'Missouri' },
          { value: 'MT', label: 'Montana' },
          { value: 'NE', label: 'Nebraska' },
          { value: 'NV', label: 'Nevada' },
          { value: 'NH', label: 'New Hampshire' },
          { value: 'NJ', label: 'New Jersey' },
          { value: 'NM', label: 'New Mexico' },
          { value: 'NY', label: 'New York' },
          { value: 'NC', label: 'North Carolina' },
          { value: 'ND', label: 'North Dakota' },
          { value: 'OH', label: 'Ohio' },
          { value: 'OK', label: 'Oklahoma' },
          { value: 'OR', label: 'Oregon' },
          { value: 'PA', label: 'Pennsylvania' },
          { value: 'RI', label: 'Rhode Island' },
          { value: 'SC', label: 'South Carolina' },
          { value: 'SD', label: 'South Dakota' },
          { value: 'TN', label: 'Tennessee' },
          { value: 'TX', label: 'Texas' },
          { value: 'UT', label: 'Utah' },
          { value: 'VT', label: 'Vermont' },
          { value: 'VA', label: 'Virginia' },
          { value: 'WA', label: 'Washington' },
          { value: 'WV', label: 'West Virginia' },
          { value: 'WI', label: 'Wisconsin' },
          { value: 'WY', label: 'Wyoming' }
        ],
      },
      {
        id: 'zip',
        label: 'ZIP',
        type: 'text',
        autocomplete: 'postal-code',
        required: true,
      },
    ],
  };

  return Response.json(form);
}
